<?php

/**
 * OpenSSH server daemon controller.
 *
 * @category   apps
 * @package    ssh-server
 * @subpackage controllers
 * @author     ClearFoundation <developer@clearfoundation.com>
 * @copyright  2011 ClearFoundation
 * @license    http://www.gnu.org/copyleft/gpl.html GNU General Public License version 3 or later
 * @link       http://www.clearfoundation.com/docs/developer/apps/ssh_server/
 */

///////////////////////////////////////////////////////////////////////////////
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
// B O O T S T R A P
///////////////////////////////////////////////////////////////////////////////

$bootstrap = getenv('CLEAROS_BOOTSTRAP') ? getenv('CLEAROS_BOOTSTRAP') : '/usr/clearos/framework/shared';
require_once $bootstrap . '/bootstrap.php';

///////////////////////////////////////////////////////////////////////////////
// D E P E N D E N C I E S
///////////////////////////////////////////////////////////////////////////////

require clearos_app_base('base') . '/controllers/daemon.php';

///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

/**
 * ClearLIFE server daemon controller.
 *
 * @category   apps
 * @package    ClearLIFE
 * @subpackage controllers
 * @author     ClearFoundation <developer@clearfoundation.com>
 * @copyright  2021 ClearFoundation
 * @license    http://www.gnu.org/copyleft/gpl.html GNU General Public License version 3 or later
 * @link       http://www.clearfoundation.com/docs/developer/apps/ssh_server/
 */

class Server extends Daemon
{
    /**
     * ClearLIFE server constructor.
     */

    function __construct() 
    {
        parent::__construct('clearlifed', 'clearlife');
    }

    /**
     * Full daemon status.
     *
     * @return json daemon status encoded in json
     */

    function full_status() 
    {
        header('Cache-Control: no-cache, must-revalidate');
        header('Content-type: application/json');

        $this->load->library('clearlife/Clearlife');

        $res['did'] = NULL;
        $res['status'] = 'stopped';
        $res['is_node_synced'] = FALSE;

        $qr_code_loaded = isset($_GET['qr_code_loaded']) ? $_GET['qr_code_loaded'] : FALSE;

        try {
            $is_node_synced = $this->clearlife->get_node_sync_status();
            $status = $this->clearlife->get_status();

            if (isset($status->data) && isset($status->data->did)) {
                $did = $status->data->did;
            }

            $res['status'] = "running";
            $res['is_node_synced'] = $is_node_synced;
            $res['did'] = $did;

            // If user comes first time, send them a QR code on screen
            if (!$did && ($qr_code_loaded == FALSE || $qr_code_loaded == "false")) {
                $res['qr_image'] = $this->clearlife->get_qr_code();
                $res['qr_code_loaded'] = TRUE;
            }
        } catch (Exception $e) {
            $res['message'] = clearos_exception_message($e);
        }

        echo json_encode($res);
    }
}
